Index: trunk/Ohana/src/libdvo/include/dvo.h
===================================================================
--- trunk/Ohana/src/libdvo/include/dvo.h	(revision 35416)
+++ trunk/Ohana/src/libdvo/include/dvo.h	(revision 35755)
@@ -182,17 +182,18 @@
 /* Secfilt.flags values -- these values are 32 bit (as of PS1_V1) */
 typedef enum {
-  ID_SECF_STAR_FEW    = 0x00000001, // used within relphot: skip star
-  ID_SECF_STAR_POOR   = 0x00000002, // used within relphot: skip star
-  ID_SECF_USE_SYNTH   = 0x00000004, // synthetic photometry used in average measurement
-  ID_SECF_USE_UBERCAL = 0x00000008, // synthetic photometry used in average measurement
-  ID_SECF_HAS_PS1     = 0x00000010, // PS1 photometry used in average measurement
-  ID_SECF_HAS_STACK   = 0x00000020, // PS1 stack photometry exists
-  ID_PHOTOM_PASS_0    = 0x00000100, // average magnitude calculated in 0th pass
-  ID_PHOTOM_PASS_1    = 0x00000200, // average magnitude calculated in 1th pass
-  ID_PHOTOM_PASS_2    = 0x00000400, // average magnitude calculated in 2th pass
-  ID_PHOTOM_PASS_3    = 0x00000800, // average magnitude calculated in 3th pass
-  ID_PHOTOM_PASS_4    = 0x00001000, // average magnitude calculated in 4th pass
-  ID_PSPS_OBJ_EXT     = 0x00002000, // In PSPS ID_SECF_OBJ_EXT is moved here so it fits within 16 bits
-  ID_SECF_OBJ_EXT     = 0x01000000, // extended in this band
+  ID_SECF_STAR_FEW    	= 0x00000001, // used within relphot: skip star
+  ID_SECF_STAR_POOR   	= 0x00000002, // used within relphot: skip star
+  ID_SECF_USE_SYNTH   	= 0x00000004, // synthetic photometry used in average measurement
+  ID_SECF_USE_UBERCAL 	= 0x00000008, // synthetic photometry used in average measurement
+  ID_SECF_HAS_PS1     	= 0x00000010, // PS1 photometry used in average measurement
+  ID_SECF_HAS_STACK   	= 0x00000020, // PS1 stack photometry exists
+  ID_PHOTOM_PASS_0    	= 0x00000100, // average magnitude calculated in 0th pass
+  ID_PHOTOM_PASS_1    	= 0x00000200, // average magnitude calculated in 1th pass
+  ID_PHOTOM_PASS_2    	= 0x00000400, // average magnitude calculated in 2th pass
+  ID_PHOTOM_PASS_3    	= 0x00000800, // average magnitude calculated in 3th pass
+  ID_PHOTOM_PASS_4    	= 0x00001000, // average magnitude calculated in 4th pass
+  ID_PSPS_OBJ_EXT     	= 0x00002000, // In PSPS ID_SECF_OBJ_EXT is moved here so it fits within 16 bits
+  ID_SECF_STACK_PRIMARY = 0x00004000, // PS1 stack photometry comes from primary skycell
+  ID_SECF_OBJ_EXT       = 0x01000000, // extended in this band
 } DVOSecfiltFlags;
 
@@ -250,5 +251,5 @@
 /* definitions for parallel dvo host information 
    XXX : need better names (safer namespace)
- */
+*/
 
 typedef enum {
@@ -328,4 +329,5 @@
   double  **dec; // DEC of projection cell center
   int    **cell; // zone,band -> proj cell sequence
+  int    **projID; // zone,band -> proj cell ID
   char  ***name; // projection cell name
   
